@@ -1,10 +1,10 @@
-# @(#)$Id: Button.pm 358 2012-04-19 15:20:34Z pjf $
+# @(#)$Id: Button.pm 368 2012-07-09 23:45:58Z pjf $
 
 package HTML::FormWidgets::Button;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 358 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.14.%d', q$Rev: 368 $ =~ /\d+/gmx );
 use parent qw(HTML::FormWidgets);
 
 __PACKAGE__->mk_accessors( qw(button_name config src) );
@@ -62,7 +62,7 @@ sub _markup_button {
 
    $args->{class} = $self->class || q(markup_button submit);
 
-   return $hacc->div( $args, $html );
+   return $hacc->span( $args, $html );
 }
 
 sub _submit_button {
