@@ -1,10 +1,10 @@
-# @(#)$Id: Date.pm 358 2012-04-19 15:20:34Z pjf $
+# @(#)$Id: Date.pm 368 2012-07-09 23:45:58Z pjf $
 
 package HTML::FormWidgets::Date;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 358 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.14.%d', q$Rev: 368 $ =~ /\d+/gmx );
 use parent qw(HTML::FormWidgets);
 
 __PACKAGE__->mk_accessors( qw(config width) );
@@ -46,7 +46,7 @@ sub render_field {
    $text   .= $hacc->span( { class => q(icon_button tips),
                              id    => $self->id.q(_clear),
                              title => $clear_hint }, $icon );
-   $html   .= $hacc->span( { class => q(icon_buttons) }, $text );
+   $html   .= $text;
 
    return $html;
 }
