@@ -1,10 +1,10 @@
-# @(#)$Id: RadioGroup.pm 358 2012-04-19 15:20:34Z pjf $
+# @(#)$Id: RadioGroup.pm 368 2012-07-09 23:45:58Z pjf $
 
 package HTML::FormWidgets::RadioGroup;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 358 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.14.%d', q$Rev: 368 $ =~ /\d+/gmx );
 use parent qw(HTML::FormWidgets);
 
 __PACKAGE__->mk_accessors( qw(columns labels values) );
@@ -12,15 +12,14 @@ __PACKAGE__->mk_accessors( qw(columns labels values) );
 sub init {
    my ($self, $args) = @_;
 
-   $self->columns        ( undef );
-   $self->container_class( q(checkbox_container) );
-   $self->labels         ( undef );
-   $self->values         ( [] );
+   $self->columns( undef );
+   $self->labels ( undef );
+   $self->values ( [] );
    return;
 }
 
 sub render_field {
-   my ($self, $args) = @_;
+   my ($self, $args) = @_; my $hacc = $self->hacc;
 
    $args->{label_class} = q(radio_group);
    $args->{columns    } = $self->columns  if ($self->columns);
@@ -28,7 +27,9 @@ sub render_field {
    $args->{onchange   } = $self->onchange if ($self->onchange);
    $args->{values     } = $self->values;
 
-   return $self->hacc->radio_group( $args );
+   my $html = $hacc->radio_group( $args );
+
+   return $hacc->div( { class => q(checkbox_container) }, $html );
 }
 
 1;
